==> slap-react-native-list-item-3.0.6.tgz: package/components/Button.js <==
import React, { Component } from 'react';
import { View, Text, Animated } from 'react-native';
import PropTypes from 'prop-types';

import Touchable from './Touchable';

export default class Button extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    buttonColor: PropTypes.string,
    textColor: PropTypes.string,
    textFontSize: PropTypes.number,
    disabledButtonColor: PropTypes.string,
    disabledTextColor: PropTypes.string,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    borderColor: PropTypes.string,
    buttonStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    isDisabled: PropTypes.bool,
    onPress: PropTypes.func,
    icon: PropTypes.element,
    marginTop: PropTypes.number,
    marginLeft: PropTypes.number,
    iconBorderRightColor: PropTypes.string,
    isValid: PropTypes.bool,
    elevation: PropTypes.number,
    error: PropTypes.string,
    name: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
    paddingHorizontal: PropTypes.number
  };

  static defaultProps = {
    children: '',
    buttonColor: '#4d4d4d',
    textColor: '#ffffff',
    textFontSize: 16,
    disabledButtonColor: '#cfcfcf',
    disabledTextColor: '#ffffff',
    borderRadius: 3,
    borderWidth: 0,
    borderColor: '#4d4d4d',
    buttonStyle: {},
    textStyle: {},
    isDisabled: false,
    onPress: () => {},
    icon: null,
    marginTop: 0,
    marginLeft: 0,
    iconBorderRightColor: 'rgba(0, 0, 0, 0.1)',
    isValid: true,
    elevation: 0,
    error: '',
    name: '',
    width: null,
    height: 45,
    paddingHorizontal: 15
  };

  animatedValue = new Animated.Value(0);

  animatedRotateZ = this.animatedValue.interpolate({
    inputRange: [0, 0.125, 0.25, 0.375, 0.5, 0.625, 0.75, 0.875, 1],
    outputRange: ['0deg', '3deg', '-3deg', '3deg', '-3deg', '3deg', '-3deg', '3deg', '0deg']
  });

  isAnimationDone = true;

  onPressButton = () => {
    if (!this.isAnimationDone) {
      return;
    }

    this.isAnimationDone = false;

    setTimeout(() => {
      this.isAnimationDone = true;
    }, 1000);

    if (!this.props.isValid) {
      Animated.sequence([
        Animated.timing(this.animatedValue, {
          toValue: 1,
          duration: 750
        }),
        Animated.timing(this.animatedValue, {
          toValue: 0,
          duration: 0
        })
      ]).start();
    }

    this.props.onPress(this.props.error, this.props.name);
  };

  render() {
    return (
      <Touchable onPress={this.onPressButton} disabled={this.props.isDisabled}>
        <Animated.View
          style={[
            {
              alignItems: 'center',
              justifyContent: 'center',
              borderRadius: this.props.borderRadius,
              borderWidth: this.props.borderWidth,
              borderColor: this.props.borderColor,
              backgroundColor: this.props.isDisabled ? this.props.disabledButtonColor : this.props.buttonColor,
              marginTop: this.props.marginTop,
              marginLeft: this.props.marginLeft,
              transform: [{ rotateZ: this.animatedRotateZ }],
              elevation: this.props.elevation,
              shadowOpacity: 0.3,
              shadowRadius: 4,
              shadowOffset: {
                height: this.props.elevation,
                width: this.props.elevation
              },
              width: this.props.width,
              height: this.props.height,
              paddingHorizontal: this.props.paddingHorizontal
            },
            this.props.buttonStyle
          ]}
        >
          { this.props.icon &&
            <View style={{
              justifyContent: 'center',
              alignItems: 'center',
              position: 'absolute',
              top: 8,
              left: 0,
              width: 50,
              height: 30,
              borderRightWidth: 1,
              borderRightColor: this.props.iconBorderRightColor
            }}
            >
              { this.props.icon }
            </View>
          }
          { typeof this.props.children == 'string' &&
            <Text
              style={[
                {
                  color: this.props.isDisabled ? this.props.disabledTextColor : this.props.textColor,
                  fontSize: this.props.textFontSize
                },
                this.props.textStyle
              ]}
            >
              { this.props.children }
            </Text>
          }
          { typeof this.props.children != 'string' &&
            this.props.children
          }
        </Animated.View>
      </Touchable>
    );
  }
}

==> slap-react-native-list-item-3.0.12.tgz: package/components/Button.js <==
import React, { Component } from 'react';
import { View, Animated } from 'react-native';
import PropTypes from 'prop-types';

import Touchable from './Touchable';
import Font from './Font';

export default class Button extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    buttonColor: PropTypes.string,
    textColor: PropTypes.string,
    textFontSize: PropTypes.number,
    disabledButtonColor: PropTypes.string,
    disabledTextColor: PropTypes.string,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    borderColor: PropTypes.string,
    buttonStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    isDisabled: PropTypes.bool,
    onPress: PropTypes.func,
    icon: PropTypes.element,
    marginTop: PropTypes.number,
    marginLeft: PropTypes.number,
    iconBorderRightColor: PropTypes.string,
    isValid: PropTypes.bool,
    elevation: PropTypes.number,
    error: PropTypes.string,
    name: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
    paddingHorizontal: PropTypes.number,
    debounce: PropTypes.number
  };

  static defaultProps = {
    children: '',
    buttonColor: '#4d4d4d',
    textColor: '#ffffff',
    textFontSize: 16,
    disabledButtonColor: '#cfcfcf',
    disabledTextColor: '#ffffff',
    borderRadius: 3,
    borderWidth: 0,
    borderColor: '#4d4d4d',
    buttonStyle: {},
    textStyle: {},
    isDisabled: false,
    onPress: () => {},
    icon: null,
    marginTop: 0,
    marginLeft: 0,
    iconBorderRightColor: 'rgba(0, 0, 0, 0.1)',
    isValid: true,
    elevation: 0,
    error: '',
    name: '',
    width: null,
    height: 45,
    paddingHorizontal: 15,
    debounce: 1000
  };

  animatedValue = new Animated.Value(0);

  animatedRotateZ = this.animatedValue.interpolate({
    inputRange: [0, 0.125, 0.25, 0.375, 0.5, 0.625, 0.75, 0.875, 1],
    outputRange: ['0deg', '3deg', '-3deg', '3deg', '-3deg', '3deg', '-3deg', '3deg', '0deg']
  });

  isButtonPressed = false;

  onPressButton = () => {
    if (this.isButtonPressed) {
      return;
    }

    this.isButtonPressed = true;

    setTimeout(() => {
      this.isButtonPressed = false;
    }, this.props.debounce);

    if (!this.props.isValid) {
      Animated.sequence([
        Animated.timing(this.animatedValue, {
          toValue: 1,
          duration: 750
        }),
        Animated.timing(this.animatedValue, {
          toValue: 0,
          duration: 0
        })
      ]).start();
    }

    this.props.onPress(this.props.error, this.props.name);
  };

  render() {
    return (
      <Touchable onPress={this.onPressButton} isDisabled={this.props.isDisabled} debounce={this.props.debounce}>
        <Animated.View
          style={[
            {
              alignItems: 'center',
              justifyContent: 'center',
              borderRadius: this.props.borderRadius,
              borderWidth: this.props.borderWidth,
              borderColor: this.props.borderColor,
              backgroundColor: this.props.isDisabled ? this.props.disabledButtonColor : this.props.buttonColor,
              marginTop: this.props.marginTop,
              marginLeft: this.props.marginLeft,
              transform: [{ rotateZ: this.animatedRotateZ }],
              elevation: this.props.elevation,
              shadowOpacity: 0.3,
              shadowRadius: 4,
              shadowOffset: {
                height: this.props.elevation,
                width: this.props.elevation
              },
              width: this.props.width,
              height: this.props.height,
              paddingHorizontal: this.props.paddingHorizontal
            },
            this.props.buttonStyle
          ]}
        >
          { this.props.icon &&
            <View style={{
              justifyContent: 'center',
              alignItems: 'center',
              position: 'absolute',
              top: 8,
              left: 0,
              width: 50,
              height: 30,
              borderRightWidth: 1,
              borderRightColor: this.props.iconBorderRightColor
            }}
            >
              { this.props.icon }
            </View>
          }
          { typeof this.props.children == 'string' &&
            <Font.H3
              color={this.props.isDisabled ? this.props.disabledTextColor : this.props.textColor}
              fontSize={this.props.textFontSize}
              style={this.props.textStyle}
            >
              { this.props.children }
            </Font.H3>
          }
          { typeof this.props.children != 'string' &&
            this.props.children
          }
        </Animated.View>
      </Touchable>
    );
  }
}
